package de.aitronic.scannerdemo;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.ListView;
import android.widget.RadioButton;
import android.widget.Switch;

import java.util.ArrayList;

import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnCheckedChanged;
import butterknife.OnClick;
import de.aitronic.scannerdemo.utils.SoundManager;

public class MainActivity extends AppCompatActivity {

    @BindView(R.id.codes_lv)
    ListView lvCodes;
    @BindView(R.id.rbBarcode)
    RadioButton rbBarcode;
    @BindView(R.id.rbRFID)
    RadioButton rbRFID;
    @BindView(R.id.swEnable2o5)
    Switch swEnable2o5;

    ArrayList<String> codes = new ArrayList();
    ArrayAdapter<String> lvAdapter;

    SoundManager soundManager;

    BroadcastReceiver scanBroadcastReceiver = new BroadcastReceiver() {
        @Override
        public void onReceive(Context context, Intent intent) {
            String result = intent.getStringExtra("data");
            String type = intent.getStringExtra("type");
            Log.e("Scanner", "Scan Completed: Data: " + result + " Type: " + type);
            codes.add(type+": "+result);
            lvAdapter.notifyDataSetChanged();
            lvCodes.post(new Runnable(){
                public void run() {
                    lvCodes.setSelection(lvCodes.getCount() - 1);
                }});

            soundManager.playSound(1);
        }
    };


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        ButterKnife.bind(this);
    }


    @Override
    protected void onResume() {
        super.onResume();
        init();
    }

    @Override
    protected void onPause() {
        shutdown();
        super.onPause();
    }


    private void init() {
        soundManager = SoundManager.getInstance(MainActivity.this);

        lvAdapter = new ArrayAdapter<String>(this, android.R.layout.simple_list_item_1, codes);
        lvCodes.setAdapter(lvAdapter);

        IntentFilter filters = new IntentFilter();
        filters.addAction("de.aitronic.SCAN_DATA");
        registerReceiver(scanBroadcastReceiver, filters);
        if (rbBarcode.isChecked()){
            setTypesToScan(true);
        }else{
            setTypesToScan(false);
        }
    }


    private void shutdown() {
        unregisterReceiver(scanBroadcastReceiver);
        resetTypesToScan();
    }


    @OnClick({R.id.rbBarcode, R.id.rbRFID})
    public void checkRadioButton(View v) {
        if (v.getId() == R.id.rbBarcode)
            setTypesToScan(true);
        else
            setTypesToScan(false);
    }

    @OnCheckedChanged(R.id.swEnable2o5)
    public void enable2o5(){
        Intent i = new Intent("de.aitronic.scanner.CONFIG_TWOD");
        String[] config = new String[6];

        if (swEnable2o5.isChecked()) {
            config[0] = "6;1;bool"; // Interleaved active
            config[3] = "5;1;bool"; // Discreet active
        }
        else {
            config[0] = "6;0;bool"; // Interleaved inactive
            config[3] = "5;0;bool"; // Discreet inactive
        }

        config[1] = "22;0;int"; // min length interleaved
        config[2] = "23;30;int"; // max length interleaved
        config[4] = "20;0;int"; // min length discreet
        config[5] = "21;30;int"; // max length discreet

        i.putExtra("config", config);
        sendBroadcast(i);
    }



    /**
     *
     * @param barcode - enable barcode or rfid
     *
     *                0001 = Barcode
     *                0010 = RFID
     *                0100 = LF
     *                1000 = UHF
     *
     *                beliebig kombinierbar, also ist z.B. 1111 für alles aktiviert möglich,
     *                aber nicht empfohlen
     *
     */
    private void setTypesToScan(boolean barcode) {
        Intent i = new Intent("de.aitronic.scanner.SCANNER_TYPES_SET");
        if (barcode)
            i.putExtra("scanner_types", 1);
        else
            i.putExtra("scanner_types", 14);
        sendBroadcast(i);
    }


    /**
     *  Zurücksetzen der Aktivierungen auf "nichts" aktiviert
     */
    private void resetTypesToScan() {
        Intent i = new Intent("de.aitronic.scanner.SCANNER_TYPES_SET");
        i.putExtra("scanner_types", 0);
        sendBroadcast(i);
    }
}
